@@ -1,5 +1,6 @@
 from . import application
 from . import controller
-from .logger import logger, ErrorLog
+# from .logger import logger, ErrorLog
 from .config import configuration
 from .filter import filter
+from .plugin import plugin
