@@ -24,8 +24,12 @@ class deflautConfig:
 
     plugin_path = "{appPath}/plugin"
 
+    plugin_list = []
+
     filter_path = "{appPath}/filter"
 
+    filter_list = []
+
     core = "*"
 
     cookie_id = "alauda_app_id"
